==> tecfy_corev2_package-1.1.78.tar.gz: lib/views/components/entity_filter/property_filter.componenet.dart <==
part of tecfy_corev2_client_package;

class PorpertyFilterComponent extends StatefulWidget {
  final Property property;
  final dynamic value;
  final void Function(dynamic)? onChange;
  PorpertyFilterComponent({required this.property, this.onChange, this.value});
  @override
  _PorpertyFilterComponentState createState() =>
      _PorpertyFilterComponentState();
}

class _PorpertyFilterComponentState extends State<PorpertyFilterComponent> {
  TextEditingController? _textController;
  late FocusNode _focusNode;
  dynamic _initValue;
  bool _isVisible = true;
  @override
  void initState() {
    _focusNode = FocusNode();
    _init();
    super.initState();
  }

  @override
  void dispose() {
    _focusNode.dispose();
    _textController?.dispose();
    super.dispose();
  }

  _init() async {
    _initValue = widget.value;
    if (_initValue == null) {
      Map<String, dynamic> data = {};
      // await widget.property.getDefaultValue(data);    // comment this line to avoid force filter by date
      _initValue = data[widget.property.dbName];
      widget.onChange?.call(_initValue);
    }
    if (widget.property.propertyType == PropertyTypes.Text ||
        widget.property.propertyType == PropertyTypes.Number) {
      if (_textController == null) {
        _textController =
            TextEditingController(text: _initValue?.toString() ?? '');

        _textController?.addListener(() {
          _submitChages();
        });
      } else {
        _textController?.text = _initValue?.toString() ?? '';
      }
    }
    await Future.delayed(Duration(milliseconds: 10));
    setState(() {});
  }

  _submitChages() {
    if (widget.onChange == null) return;
    if (widget.property.propertyType == PropertyTypes.Text) {
      _initValue = _textController?.text;
      widget.onChange?.call(_textController?.text);
    }
    if (widget.property.propertyType == PropertyTypes.Number) {
      _initValue = num.tryParse(_textController!.text);
      widget.onChange?.call(_initValue);
    }
  }

  @override
  Widget build(BuildContext context) {
    // widget.property.isVisible(widget.data, widget.entity).then((isVisible) {
    //   if (isVisible != _isVisible) {
    //     _isVisible = isVisible;
    //     setState(() {});
    //   }
    // });

    if (!_isVisible || (!widget.property.isAdd && !widget.property.isEdit))
      return Container();

    // if (_initValue != widget.value) _init();

    switch (widget.property.propertyType) {
      case PropertyTypes.Dropdown:
        var prop = (widget.property as PropertyDropdown);
        if (prop.options != null) {
          return DropdownComponenet(
            label: widget.property.name,
            description: widget.property.description,
            options: prop.options,
            readOnly: widget.property.readOnly,
            displayProperty: LocalConfigService.isArabic ? 'nameAr' : 'nameEn',
            idProperty: '_id',
            initalValue: widget.value,
            onChanged: (v) => widget.onChange?.call(v),
          );
        }
        return DropdownAdvancedEntity(prop.entityName,
            label: widget.property.name,
            isAddNew: true,
            description: widget.property.description,
            entity: EntityService.getEntity(prop.entityName)!,
            url: prop.dropdownUrl,
            property: prop,
            readOnly: widget.property.readOnly,
            data: {widget.property.dbName: widget.value},
            onChanged: (v) => widget.onChange?.call(v));

      // final entity = EntityService.getEntity(
      //     (widget.property as PropertyDropdown).entityName);
      // if (entity != null) {
      //   return DropdownAdvancedEntity(
      //     (widget.property as PropertyDropdown).entityName,
      //     label: widget.property.name,
      //     entity: entity,
      //     url: (widget.property as PropertyDropdown).dropdownUrl,
      //     property: (widget.property as PropertyDropdown),
      //     isRequired: widget.property.isRequired,
      //     data: {widget.property.dbName: widget.value},
      //     onChanged: (v, data) => widget.onChange?.call(v),
      //   );
      // } else {
      //   if((widget.property as PropertyDropdown).entityName.isEmpty && )
      //   return Text(widget.property.dbName);
      // }

      case PropertyTypes.Text:
        if ((widget.property as PropertyText).isPassword) return Container();
        return AppTextFormField(
          textDirection: LocalConfigService.isArabic &&
                  !(widget.property as PropertyText).isEmail
              ? TextDirection.rtl
              : TextDirection.ltr,
          labelText: widget.property.name,
          focusNode: _focusNode,
          controller: _textController,
          onFieldSubmitted: (v) => _focusNode.unfocus(),
          textInputAction: TextInputAction.next,
          isRequired: widget.property.isRequired,
          keyboardType: (widget.property as PropertyText).isEmail
              ? TextInputType.emailAddress
              : TextInputType.text,
          maxLines: 1,
          onEditingComplete: _submitChages,
        );
      case PropertyTypes.Number:
        return AppTextFormField(
            labelText: widget.property.name,
            controller: _textController,
            focusNode: _focusNode,
            isRequired: widget.property.isRequired,
            onFieldSubmitted: (v) => _focusNode.unfocus(),
            textInputAction: TextInputAction.next,
            keyboardType: TextInputType.number,
            onEditingComplete: _submitChages);
      case PropertyTypes.Boolean:
        return AppCheckBox(
            label: widget.property.name,
            initalValue: _initValue,
            onChanged: (v) => widget.onChange?.call(v));

      case PropertyTypes.Color:
        return ColorPropertyComponenet(
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            label: widget.property.name,
            onChanged: (v) => widget.onChange?.call(v));

      case PropertyTypes.Date:
        return DateProperty(
            label: widget.property.name,
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            onChanged: (v) {
              widget.onChange?.call(v);
            });

      default:
        return Container();
    }
  }
}

==> tecfy_corev2_package-1.1.106.tar.gz: lib/views/components/entity_filter/property_filter.componenet.dart <==
part of tecfy_corev2_client_package;

class PorpertyFilterComponent extends StatefulWidget {
  final Property property;
  final dynamic value;
  final void Function(dynamic)? onChange;
  PorpertyFilterComponent({required this.property, this.onChange, this.value});
  @override
  _PorpertyFilterComponentState createState() =>
      _PorpertyFilterComponentState();
}

class _PorpertyFilterComponentState extends State<PorpertyFilterComponent> {
  TextEditingController? _textController;
  late FocusNode _focusNode;
  dynamic _initValue;
  bool _isVisible = true;
  @override
  void initState() {
    _focusNode = FocusNode();
    _init();
    super.initState();
  }

  @override
  void dispose() {
    _focusNode.dispose();
    _textController?.dispose();
    super.dispose();
  }

  _init() async {
    _initValue = widget.value;
    // if (_initValue == null) {
    //   Map<String, dynamic> data = {};
    //   // await widget.property.getDefaultValue(data);    // comment this line to avoid force filter by date
    //   _initValue = data[widget.property.dbName];
    //   widget.onChange?.call(_initValue);
    // }
    if (widget.property.propertyType == PropertyTypes.Text ||
        widget.property.propertyType == PropertyTypes.Number) {
      if (_textController == null) {
        _textController =
            TextEditingController(text: _initValue?.toString() ?? '');

        _textController?.addListener(() {
          _submitChages();
        });
      } else {
        _textController?.text = _initValue?.toString() ?? '';
      }
    }
    await Future.delayed(Duration(milliseconds: 10));
    setState(() {});
  }

  _submitChages() {
    if (widget.onChange == null) return;
    if (widget.property.propertyType == PropertyTypes.Text) {
      _initValue = _textController?.text;
      widget.onChange?.call(_textController?.text);
    }
    if (widget.property.propertyType == PropertyTypes.Number) {
      _initValue = num.tryParse(_textController!.text);
      widget.onChange?.call(_initValue);
    }
  }

  @override
  Widget build(BuildContext context) {
    // widget.property.isVisible(widget.data, widget.entity).then((isVisible) {
    //   if (isVisible != _isVisible) {
    //     _isVisible = isVisible;
    //     setState(() {});
    //   }
    // });

    if (!_isVisible || (!widget.property.isAdd && !widget.property.isEdit))
      return Container();

    // if (_initValue != widget.value) _init();

    switch (widget.property.propertyType) {
      case PropertyTypes.Dropdown:
        var prop = (widget.property as PropertyDropdown);
        if (prop.options != null) {
          return DropdownComponenet(
            label: widget.property.name,
            description: widget.property.description,
            options: prop.options,
            readOnly: widget.property.readOnly,
            displayProperty: LocalConfigService.isArabic ? 'nameAr' : 'nameEn',
            idProperty: '_id',
            initalValue: widget.value,
            onChanged: (v) => widget.onChange?.call(v),
          );
        }
        return DropdownAdvancedEntity(prop.entityName,
            label: widget.property.name,
            isAddNew: true,
            description: widget.property.description,
            entity: EntityService.getEntity(prop.entityName)!,
            url: prop.dropdownUrl,
            property: prop,
            readOnly: widget.property.readOnly,
            data: {widget.property.dbName: widget.value},
            onChanged: (v) => widget.onChange?.call(v));

      // final entity = EntityService.getEntity(
      //     (widget.property as PropertyDropdown).entityName);
      // if (entity != null) {
      //   return DropdownAdvancedEntity(
      //     (widget.property as PropertyDropdown).entityName,
      //     label: widget.property.name,
      //     entity: entity,
      //     url: (widget.property as PropertyDropdown).dropdownUrl,
      //     property: (widget.property as PropertyDropdown),
      //     isRequired: widget.property.isRequired,
      //     data: {widget.property.dbName: widget.value},
      //     onChanged: (v, data) => widget.onChange?.call(v),
      //   );
      // } else {
      //   if((widget.property as PropertyDropdown).entityName.isEmpty && )
      //   return Text(widget.property.dbName);
      // }

      case PropertyTypes.Text:
        if ((widget.property as PropertyText).isPassword) return Container();
        return AppTextFormField(
          textDirection: LocalConfigService.isArabic &&
                  !(widget.property as PropertyText).isEmail
              ? TextDirection.rtl
              : TextDirection.ltr,
          labelText: widget.property.name,
          focusNode: _focusNode,
          controller: _textController,
          onFieldSubmitted: (v) => _focusNode.unfocus(),
          textInputAction: TextInputAction.next,
          isRequired: widget.property.isRequired,
          keyboardType: (widget.property as PropertyText).isEmail
              ? TextInputType.emailAddress
              : TextInputType.text,
          maxLines: 1,
          onEditingComplete: _submitChages,
        );
      case PropertyTypes.Number:
        return AppTextFormField(
            labelText: widget.property.name,
            controller: _textController,
            focusNode: _focusNode,
            isRequired: widget.property.isRequired,
            onFieldSubmitted: (v) => _focusNode.unfocus(),
            textInputAction: TextInputAction.next,
            keyboardType: TextInputType.number,
            onEditingComplete: _submitChages);
      case PropertyTypes.Boolean:
        return AppCheckBox(
            label: widget.property.name,
            initalValue: _initValue ?? false,
            onChanged: (v) => widget.onChange?.call(v));

      case PropertyTypes.Color:
        return ColorPropertyComponenet(
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            label: widget.property.name,
            onChanged: (v) => widget.onChange?.call(v));

      case PropertyTypes.Date:
        return DateProperty(
            label: widget.property.name,
            initalValue: _initValue,
            isRequired: widget.property.isRequired,
            onChanged: (v) {
              widget.onChange?.call(v);
            });

      default:
        return Container();
    }
  }
}
